==> apache-cxf-3.6.9-src.zip: apache-cxf-3.6.9-src/systests/jaxrs/src/test/java/org/apache/cxf/systest/jaxrs/failover/FailoverBookStore.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxrs.failover;


import javax.ws.rs.GET;
import javax.ws.rs.NotFoundException;
import javax.ws.rs.Path;
import javax.ws.rs.ServiceUnavailableException;

import org.apache.cxf.systest.jaxrs.Book;

/**
 * Just allow one invocation + then return 404
 */
@Path("/bookstore")
public class FailoverBookStore {

    private int counter;
    private int unavailableCounter;

    @GET
    @Path("/")
    public Book getBookRoot() {
        if (counter != 0) {
            throw new NotFoundException();
        }
        counter++;
        return new Book("root", 124L);
    }

    
    @GET
    @Path("/unavailable")
    public Book getBookRootUnavailable() {
        if (unavailableCounter++ < 4) {
            throw new ServiceUnavailableException();
        }
        return new Book("root", 124L);
    }
}

==> apache-cxf-4.1.2-src.zip: apache-cxf-4.1.2-src/systests/jaxrs/src/test/java/org/apache/cxf/systest/jaxrs/failover/FailoverBookStore.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxrs.failover;


import jakarta.ws.rs.GET;
import jakarta.ws.rs.NotFoundException;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.ServiceUnavailableException;
import org.apache.cxf.systest.jaxrs.Book;

/**
 * Just allow one invocation + then return 404
 */
@Path("/bookstore")
public class FailoverBookStore {

    private int counter;
    private int unavailableCounter;

    @GET
    @Path("/")
    public Book getBookRoot() {
        if (counter != 0) {
            throw new NotFoundException();
        }
        counter++;
        return new Book("root", 124L);
    }

    
    @GET
    @Path("/unavailable")
    public Book getBookRootUnavailable() {
        if (unavailableCounter++ < 4) {
            throw new ServiceUnavailableException();
        }
        return new Book("root", 124L);
    }
}
